@@ -357,8 +357,7 @@ get_rel_infos(migratorContext *ctx, const char *db_name, RelInfoArr *relarr,
 				"   LEFT OUTER JOIN pg_catalog.pg_tablespace t "
 				"	ON c.reltablespace = t.oid "
 				"WHERE (( n.nspname NOT IN ('pg_catalog', 'information_schema') "
-				"	AND c.oid >= "
-				STRINGIFY(FirstNormalObjectId) " "
+				"	AND c.oid >= %u "
 				"	) OR ( "
 				"	n.nspname = 'pg_catalog' "
 				"	AND (relname = 'pg_largeobject' OR "
@@ -370,6 +369,7 @@ get_rel_infos(migratorContext *ctx, const char *db_name, RelInfoArr *relarr,
 				"			c.reltoastrelid, t.spclocation, "
 				"			n.nspname "
 				"ORDER BY n.nspname, c.relname;",
+				FirstNormalObjectId,
 				/* see the comment at the top of v8_3_adjust_sequences() */
 				(GET_MAJOR_VERSION(ctx->old.pg_version) <= 803 &&
 				 GET_MAJOR_VERSION(ctx->new.pg_version) >= 804) ?
@@ -481,8 +481,8 @@ get_loadable_libraries(migratorContext *ctx)
 										"FROM	pg_catalog.pg_proc "
 										"WHERE	prolang = 13 /* C */ AND "
 										"		probin IS NOT NULL AND "
-										"		oid >= "
-										STRINGIFY(FirstNormalObjectId) ";");
+										"		oid >= %u;",
+										FirstNormalObjectId);
 		totaltups += PQntuples(ress[dbnum]);
 
 		PQfinish(conn);
