@@ -24,12 +24,13 @@ static void split_old_dump(migratorContext *ctx);
 static void copy_clog_xlog_xid(migratorContext *ctx);
 static void set_frozenxids(migratorContext *ctx);
 static void check_cluster_versions(migratorContext *ctx);
-static void check_cluster_compatibility(migratorContext *ctx);
-static void setup(migratorContext *ctx, char *argv0);
+static void check_cluster_compatibility(migratorContext *ctx, bool live_check);
+static void setup(migratorContext *ctx, char *argv0, bool live_check);
 static void cleanup(migratorContext *ctx);
 static void rename_old_pg_control(migratorContext *ctx);
 
-
+/* OID system catalog preservation added during PG 8.5 development */
+#define OID_PRESERVATION_CAT_VER	200912271
 
 /*
  *	main
@@ -39,40 +40,59 @@ main(int argc, char **argv)
 {
 	migratorContext ctx;
 	char *sequence_script_file_name = NULL;
+	bool	live_check = false;
 	
 	memset(&ctx, 0, sizeof(ctx));
 
 	parseCommandLine(&ctx, argc, argv);
 
-	pg_log(&ctx, PG_REPORT, "Performing consistency checks\n");
-	pg_log(&ctx, PG_REPORT, "-----------------------------\n");
-	setup(&ctx, argv[0]);
+	if (ctx.check && is_server_running(&ctx, ctx.old.pgdata))
+	{
+		live_check = true;
+		if (ctx.old.port == ctx.new.port)
+			pg_log(&ctx, PG_FATAL, "When checking a live server, "
+					"the old and new port numbers must be different.\n");
+		pg_log(&ctx, PG_REPORT, "Performing consistency checks on old live server\n");
+		pg_log(&ctx, PG_REPORT, "------------------------------------------------\n");
+	}
+	else
+	{
+		pg_log(&ctx, PG_REPORT, "Performing consistency checks\n");
+		pg_log(&ctx, PG_REPORT, "-----------------------------\n");
+	}
+
+	setup(&ctx, argv[0], live_check);
 
 	check_cluster_versions(&ctx);
-	check_cluster_compatibility(&ctx);
+	check_cluster_compatibility(&ctx, live_check);
 
 
 	/* -- OLD -- */
-	start_postmaster(&ctx, CLUSTER_OLD, false);
+
+	if (!live_check)
+		start_postmaster(&ctx, CLUSTER_OLD, false);
 
 	set_locale_and_encoding(&ctx, CLUSTER_OLD);
 	
 	get_pg_database_relfilenode(&ctx, CLUSTER_OLD);
 
-	get_autovacuum_freeze_max_age(&ctx, CLUSTER_OLD);
-
 	/* Extract a list of databases and tables from the old cluster */
 	get_db_and_rel_infos(&ctx, &ctx.old.dbarr, CLUSTER_OLD);
 
-	/* And some other stuff too */
 	get_tablespace_paths(&ctx);
 	get_loadable_libraries(&ctx);
 
-	check_for_composite_types(&ctx, CLUSTER_OLD);
-	check_for_array_types(&ctx, CLUSTER_OLD);
-	check_for_enum_types(&ctx, CLUSTER_OLD);
+	/*
+	 *	Check for various failure cases
+	 */
+
+	if (ctx.new.controldata.cat_ver < OID_PRESERVATION_CAT_VER)
+	{
+		v_8_4_check_for_composite_types(&ctx, CLUSTER_OLD);
+		v_8_4_check_for_array_types(&ctx, CLUSTER_OLD);
+		v_8_4_check_for_enum_types(&ctx, CLUSTER_OLD);
+	}
 
-	/* Check for various failure cases */
 	v8_3_check_for_isn_and_int8_passing_mismatch(&ctx, CLUSTER_OLD);
 	if (GET_MAJOR_VERSION(ctx.old.pg_version) <= 803 &&
 		GET_MAJOR_VERSION(ctx.new.pg_version) >= 804)
@@ -98,11 +118,11 @@ main(int argc, char **argv)
 		GET_MAJOR_VERSION(ctx.new.pg_version) >= 805)
 		v8_4_populate_pg_largeobject_metadata(&ctx, true, CLUSTER_OLD);
 
-	/* Looks okay so far.  Prepare the pg_dump output */
 	generate_old_dump(&ctx);
 	split_old_dump(&ctx);
 
-	stop_postmaster(&ctx, false, false);
+	if (!live_check)
+		stop_postmaster(&ctx, false, false);
 
 
 	/* -- NEW -- */
@@ -114,16 +134,10 @@ main(int argc, char **argv)
 
 	check_loadable_libraries(&ctx);
 
-	get_autovacuum_freeze_max_age(&ctx, CLUSTER_NEW);
-
 	stop_postmaster(&ctx, false, false);
 
 	check_locale_and_encoding(&ctx, &ctx.old.controldata, &ctx.new.controldata);
 
-	if (ctx.old.autovacuum_freeze_max_age > ctx.new.autovacuum_freeze_max_age)
-		pg_log(&ctx, PG_FATAL,
-			   "old cluster has a greater autovacuum_freeze_max_age than the new cluster\n");
-
 	if (ctx.transfer_mode == TRANSFER_MODE_LINK)
 		check_hard_link(&ctx);
 	
@@ -206,7 +220,7 @@ main(int argc, char **argv)
 	start_postmaster(&ctx, CLUSTER_NEW, false);
 
 	/*
-	 *	We check autovacuum_freeze_max_age above to make sure autovacuum does
+	 *	We set autovacuum_freeze_max_age to its maximum value so autovacuum does
 	 *	not launch here and delete clog files, before the frozen xids are set.
 	 */
 
@@ -237,6 +251,8 @@ main(int argc, char **argv)
 	/* -- NEW -- */
 	start_postmaster(&ctx, CLUSTER_NEW, false);
 
+	install_support_functions(&ctx);
+
 	prep_status(&ctx, "Restoring database schema");
 	exec_prog(&ctx, true,
 			  SYSTEMQUOTE "\"%s/%s\" --set ON_ERROR_STOP=on --port %d "
@@ -249,8 +265,6 @@ main(int argc, char **argv)
 	dbarr_free(&ctx.new.dbarr);
 	get_db_and_rel_infos(&ctx, &ctx.new.dbarr, CLUSTER_NEW);
 
-	install_support_functions(&ctx);
-
 	prep_status(&ctx, "Restoring relations to use fixed toast file names\n");
 	adjust_rels_to_use_fixed_toast_relfilenodes(&ctx, &ctx.old.dbarr, &ctx.new.dbarr);
 	prep_status(&ctx, "");	/* in case nothing printed */
@@ -539,7 +553,7 @@ static void	set_frozenxids(migratorContext *ctx)
  *	setup()
  */
 static void
-setup(migratorContext *ctx, char *argv0)
+setup(migratorContext *ctx, char *argv0, bool live_check)
 {
 	char		exec_path[MAXPGPATH];	/* full path to my executable */
 
@@ -555,7 +569,7 @@ setup(migratorContext *ctx, char *argv0)
 	verify_directories(ctx);
 
 	/* no postmasters should be running */
-	if (is_server_running(ctx, ctx->old.pgdata))
+	if (!live_check && is_server_running(ctx, ctx->old.pgdata))
 	{
 		pg_log(ctx, PG_FATAL, "There seems to be a postmaster servicing the old cluster.\n"
 					  "Please shutdown that postmaster and try again.\n");
@@ -632,7 +646,7 @@ check_cluster_versions(migratorContext *ctx)
  *	check_cluster_compatibility()
  */
 static void
-check_cluster_compatibility(migratorContext *ctx)
+check_cluster_compatibility(migratorContext *ctx, bool live_check)
 {
 	char		libfile[MAXPGPATH];
 	FILE 		*lib_test;
@@ -651,8 +665,8 @@ check_cluster_compatibility(migratorContext *ctx)
 		fclose(lib_test);
 
 	/* get/check pg_control data of servers */
-	get_control_data(ctx, &ctx->old);
-	get_control_data(ctx, &ctx->new);
+	get_control_data(ctx, &ctx->old, live_check);
+	get_control_data(ctx, &ctx->new, false);
 	check_control_data(ctx, &ctx->old.controldata, &ctx->new.controldata);
 }
 
@@ -719,16 +733,54 @@ install_support_functions(migratorContext *ctx)
 		DbInfo	   *newdb = &ctx->new.dbarr.dbs[dbnum];
 		PGconn	   *conn = connectToServer(ctx, newdb->db_name, CLUSTER_NEW);
 
+		/* suppress NOTICE of dropped objects */
 		PQclear(executeQueryOrDie(ctx, conn,
-					"CREATE OR REPLACE FUNCTION public.pg_toasttbl_recreate(OID,OID) "
+					"SET client_min_messages = warning;"));
+		PQclear(executeQueryOrDie(ctx, conn,
+					"DROP SCHEMA IF EXISTS binary_upgrade CASCADE;"));
+		PQclear(executeQueryOrDie(ctx, conn,
+					"RESET client_min_messages;"));
+
+		PQclear(executeQueryOrDie(ctx, conn,
+					"CREATE SCHEMA binary_upgrade;"));
+
+		PQclear(executeQueryOrDie(ctx, conn,
+					"CREATE OR REPLACE FUNCTION binary_upgrade.pg_toasttbl_recreate(OID,OID) "
 					"RETURNS VOID "
 					"AS '$libdir/pg_migrator' "
 					"LANGUAGE C STRICT;"));
 		PQclear(executeQueryOrDie(ctx, conn,
-					"CREATE OR REPLACE FUNCTION public.pg_toasttbl_drop(OID) "
+					"CREATE OR REPLACE FUNCTION binary_upgrade.pg_toasttbl_drop(OID) "
 					"RETURNS VOID "
 					"AS '$libdir/pg_migrator' "
 					"LANGUAGE C STRICT;"));
+		if (ctx->new.controldata.cat_ver >= OID_PRESERVATION_CAT_VER)
+		{
+			PQclear(executeQueryOrDie(ctx, conn,
+						"CREATE OR REPLACE FUNCTION "
+						"		binary_upgrade.set_next_pg_type_oid(OID) "
+						"RETURNS VOID "
+						"AS '$libdir/pg_migrator_sysoids' "
+						"LANGUAGE C STRICT;"));
+			PQclear(executeQueryOrDie(ctx, conn,
+						"CREATE OR REPLACE FUNCTION "
+						"		binary_upgrade.set_next_pg_type_array_oid(OID) "
+						"RETURNS VOID "
+						"AS '$libdir/pg_migrator_sysoids' "
+						"LANGUAGE C STRICT;"));
+			PQclear(executeQueryOrDie(ctx, conn,
+						"CREATE OR REPLACE FUNCTION "
+						"		binary_upgrade.set_next_pg_type_toast_oid(OID) "
+						"RETURNS VOID "
+						"AS '$libdir/pg_migrator_sysoids' "
+						"LANGUAGE C STRICT;"));
+			PQclear(executeQueryOrDie(ctx, conn,
+						"CREATE OR REPLACE FUNCTION "
+						"		binary_upgrade.add_pg_enum_label(OID, OID, NAME) "
+						"RETURNS VOID "
+						"AS '$libdir/pg_migrator_sysoids' "
+						"LANGUAGE C STRICT;"));
+		}
 		PQfinish(conn);
 	}
 	check_ok(ctx);
@@ -753,10 +805,13 @@ uninstall_support_functions(migratorContext *ctx)
 		DbInfo	   *newdb = &ctx->new.dbarr.dbs[dbnum];
 		PGconn	   *conn = connectToServer(ctx, newdb->db_name, CLUSTER_NEW);
 
+		/* suppress NOTICE of dropped objects */
 		PQclear(executeQueryOrDie(ctx, conn,
-					"DROP FUNCTION public.pg_toasttbl_recreate(OID,OID);"));
+					"SET client_min_messages = warning;"));
 		PQclear(executeQueryOrDie(ctx, conn,
-					"DROP FUNCTION public.pg_toasttbl_drop(OID);"));
+					"DROP SCHEMA binary_upgrade CASCADE;"));
+		PQclear(executeQueryOrDie(ctx, conn,
+					"RESET client_min_messages;"));
 		PQfinish(conn);
 	}
 	check_ok(ctx);
