@@ -183,7 +183,7 @@ start_postmaster(migratorContext *ctx, Cluster whichCluster, bool quiet)
 	}
 
 	if (!quiet)
-		prep_status(ctx, "Starting postmaster to service %s cluster\n", clusterName);
+		prep_status(ctx, "Starting postmaster to service %s cluster", clusterName);
 	/* use -l for Win32 */
 	sprintf(cmd, SYSTEMQUOTE "\"%s/pg_ctl\" -l \"%s\" -D \"%s\" "
 				"-o \"-p %d -c autovacuum=off -c autovacuum_freeze_max_age=2000000000\" "
@@ -192,8 +192,6 @@ start_postmaster(migratorContext *ctx, Cluster whichCluster, bool quiet)
 	exec_prog(ctx, true, "%s", cmd);
 
 	/* wait for the server to start properly */
-	if (!quiet)
-		prep_status(ctx, "  waiting for postmaster to start");
 
 	if (test_server_conn(ctx, POSTMASTER_UPTIME, whichCluster) == false)
 		pg_log(ctx, PG_FATAL, " Unable to start postmaster with the command: %s\nPerhaps pg_hba.conf was not set to \"trust\".",
