@@ -859,7 +859,7 @@ v8_3_create_sequence_script(migratorContext *ctx, Cluster whichCluster)
 
 
 /*
- * check_for_composite_types()
+ * v_8_4_check_for_composite_types()
  *
  *	composite types have pg_type oids in their data values and
  *  pg_type.oid is not preserved between migrations.  We don't
@@ -867,7 +867,7 @@ v8_3_create_sequence_script(migratorContext *ctx, Cluster whichCluster)
  *	check arrays later
  */
 void
-check_for_composite_types(migratorContext *ctx, Cluster whichCluster)
+v_8_4_check_for_composite_types(migratorContext *ctx, Cluster whichCluster)
 {
 	ClusterInfo	*active_cluster = (whichCluster == CLUSTER_OLD) ?
 					&ctx->old : &ctx->new;
@@ -904,11 +904,11 @@ check_for_composite_types(migratorContext *ctx, Cluster whichCluster)
 								"		a.atttypid = t.oid AND "
 								"		c.relnamespace = n.oid AND "
 								"		t.typtype = 'c' AND "
-								"		t.oid >= "
-/* oids assigned by initdb might change, so use FirstBootstrapObjectId */
-									STRINGIFY(FirstBootstrapObjectId) " AND "
+								"		t.oid >= %u AND "
 								"		n.nspname != 'pg_catalog' AND "
-								"		n.nspname != 'information_schema'");
+								"		n.nspname != 'information_schema'",
+/* oids assigned by initdb might change, so use FirstBootstrapObjectId */
+								FirstBootstrapObjectId);
 
 		ntups = PQntuples(res);
 		i_nspname = PQfnumber(res, "nspname");
@@ -954,14 +954,14 @@ check_for_composite_types(migratorContext *ctx, Cluster whichCluster)
 
 
 /*
- * check_for_array_types()
+ * v_8_4_check_for_array_types()
  *
  *	array types have pg_type oids in their data values and
  *  pg_type.oid is not preserved between migrations.  We catch
  *	arrays of composite types here too.
  */
 void
-check_for_array_types(migratorContext *ctx, Cluster whichCluster)
+v_8_4_check_for_array_types(migratorContext *ctx, Cluster whichCluster)
 {
 	ClusterInfo	*active_cluster = (whichCluster == CLUSTER_OLD) ?
 					&ctx->old : &ctx->new;
@@ -1003,11 +1003,11 @@ check_for_array_types(migratorContext *ctx, Cluster whichCluster)
 								"			FROM pg_type t2 "
 								"			WHERE t2.oid = t.typelem "
 								"		) AND "
-								"		t.oid >= "
-/* oids assigned by initdb might change, so use FirstBootstrapObjectId */
-									STRINGIFY(FirstBootstrapObjectId) " AND "
+								"		t.oid >= %u AND "
 								"		n.nspname != 'pg_catalog' AND "
-								"		n.nspname != 'information_schema'");
+								"		n.nspname != 'information_schema'",
+/* oids assigned by initdb might change, so use FirstBootstrapObjectId */
+								FirstBootstrapObjectId);
 
 		ntups = PQntuples(res);
 		i_nspname = PQfnumber(res, "nspname");
@@ -1053,13 +1053,13 @@ check_for_array_types(migratorContext *ctx, Cluster whichCluster)
 
 
 /*
- * check_for_enum_types()
+ * v_8_4_check_for_enum_types()
  *
  *	enum types have pg_type oids in their data values and
  *  pg_type.oid is not preserved between migrations.
  */
 void
-check_for_enum_types(migratorContext *ctx, Cluster whichCluster)
+v_8_4_check_for_enum_types(migratorContext *ctx, Cluster whichCluster)
 {
 	ClusterInfo	*active_cluster = (whichCluster == CLUSTER_OLD) ?
 					&ctx->old : &ctx->new;
@@ -1096,11 +1096,11 @@ check_for_enum_types(migratorContext *ctx, Cluster whichCluster)
 								"		a.atttypid = t.oid AND "
 								"		c.relnamespace = n.oid AND "
 								"		t.typtype = 'e' AND "
-								"		t.oid >= "
-/* oids assigned by initdb might change, so use FirstBootstrapObjectId */
-									STRINGIFY(FirstBootstrapObjectId) " AND "
+								"		t.oid >= %u AND "
 								"		n.nspname != 'pg_catalog' AND "
-								"		n.nspname != 'information_schema'");
+								"		n.nspname != 'information_schema'",
+/* oids assigned by initdb might change, so use FirstBootstrapObjectId */
+								FirstBootstrapObjectId);
 
 		ntups = PQntuples(res);
 		i_nspname = PQfnumber(res, "nspname");
